Use Case:  Remove unneeded content
==================================

  Actor

    - Content Creator

  Assumptions

    - Content Creator has logged into the CMF (see "Login to the
      Site":LoginAsMember).

  Procedure

    1. Navigate to the content to be deleted.

       To retrieve a list of the content you have authored, see Use
       Case: "View personally authored content":ViewMyContent

    2. Select 'Folder contents' from the actions box.

    3. Select the content to be delete from by checking the corresponding
       checkbox.  Click the "Delete" button.

    4. The system will delete the content from the folder and redirect
       to the folder contents view, adding a notification message which
       indicates that the selected content has been deleted.

    5. To undo this action, see "Undo changes to content":UndoChanges
